import click
from .install_webdriver_command import check_version_and_download_driver
from .install_standalone_command import check_req_and_install_selenium_server


@click.command(name='dev-kit', help="Install local development kit (Webdriver, Selenium Server, etc)")
@click.option('-b', '--browser', type=click.Choice(['chrome', 'firefox', 'edge']), required=True)
def install_dev_kit(browser):
    check_version_and_download_driver(browser)
    check_req_and_install_selenium_server()


if __name__ == "__main__":
    install_dev_kit()



import click
import os
import requests

SELENIUM_SERVER_URL = "https://selenium-release.storage.googleapis.com/3.141/selenium-server-standalone-3.141.59.jar"
SELENIUM_SERVER_FILE = "selenium-server/selenium-server-standalone.jar"


def check_selenium_requirements():
    java_path = os.popen("which java").read().strip()
    if not java_path:
        click.secho("Java is not installed on this machine.", fg="red")
        return False

    java_version = os.popen("java -version 2>&1 | awk -F '\"' '/version/ {print $2}'").read().strip()
    major_version = java_version.split('.')[0]
    if int(major_version) < 9:
        click.secho(f"Java version {java_version} is not supported. Please install Java 9 or higher.", fg="red")
        return False

    return True


def download_selenium_server():
    response = requests.get(SELENIUM_SERVER_URL)
    os.makedirs("selenium-server", exist_ok=True)
    with open(SELENIUM_SERVER_FILE, "wb") as f:
        f.write(response.content)


def check_req_and_install_selenium_server():
    if check_selenium_requirements():
        click.secho("Downloading Selenium Standalone server ...", nl=False)
        download_selenium_server()
        click.secho("OK", fg="green")


@click.command(name="standalone", help="Install Selenium Standalone server.")
def install_selenium_standalone():
    check_req_and_install_selenium_server()


if __name__ == "__main__":
    install_selenium_standalone()



import os

from selenium.webdriver import Remote
from selenium.webdriver.common.action_chains import ActionChains

from vigilant.actions.assertions import Assertions
from vigilant.actions.finder import Finder
from vigilant.actions.waiter import Waiter
from vigilant.logger import logger as log


def get_base_url() -> str:
    """
    Get the base URL from the environment variable 'BASE_URL'.

    :return: base URL as a string
    """
    return os.environ.get('BASE_URL')


class VigilantActions:
    """
    `VigilantActions` - provide methods for interaction with browser. This is wrapper on native Selenium WebDriver
    methods for working with browser in more comfortable way, with smart waiters, finders and assertions.
    `waiter` - smart wait methods.
    `finder` - methods for comfortable elements search.
    `assertions` - assertion methods for browser.
    """

    def __init__(self, driver):
        self.driver: Remote = driver
        self.assertions: Assertions = Assertions(self.driver)
        self.finder: Finder = Finder(self.driver)
        self.waiter: Waiter = Waiter(self.driver, self.finder)

    def get_page(self, url):
        """
        Opens the page by the URL relative to the one set in the BASE_URL configuration variable.

        :param url: A path to the page relative to the BASE_URL
        :return: self
        """
        log.info(f'Getting page: {url}')
        self.driver.get(get_base_url() + url)
        return self

    def close(self):
        """
        Closes the current window.

        :return: self
        """
        log.info(f'Closing the current window')
        self.driver.close()
        return self

    def quit(self):
        """
        Quits the driver and closes every associated window.

        :return: self
        """
        log.info(f'Quits the driver and closes every associated window')
        self.driver.quit()
        return self

    def page_back(self):
        """
        Goes one step backward in the browser history.

        :return: self
        """
        log.info(f'Goes one step backward in the browser history')
        self.driver.back()
        return self

    def page_forward(self):
        """
        Goes one step forward in the browser history.

        :return: self
        """
        log.info(f'Goes one step forward in the browser history')
        self.driver.forward()
        return self

    def page_refresh(self):
        """
        Refreshes the current page.

        :return: self
        """
        log.info(f'Refreshes the current page')
        self.driver.refresh()
        return self

    def get_page_title(self):
        """
        Returns the title of the current page.

        :return: page title as a string
        """
        log.info(f'Returns the title of the current page')
        return self.driver.title

    def maximize_window(self):
        """
        Maximizes the current window that the WebDriver is using.

        :return: self
        """
        log.info(f'Maximizes the current window that webdriver is using')
        self.driver.maximize_window()
        return self

    def resize_window(self, width, height):
        """
        Sets the current window width and height.

        :param width: The desired window width in pixels
        :param height: The desired window height in pixels
        :return: self
        """
        log.info(f'Sets current window width to: {width}px and height to: {height}px')
        self.driver.set_window_size(width, height)
        return self

    def execute_js_script(self, js_script, arguments=None):
        """
        Executes a JavaScript script with optional arguments.

        :param js_script: The JavaScript script to execute
        :param arguments: Optional arguments for the script
        :return: self
        """
        log.info(f'Execute JS script: {js_script} with arguments: {arguments}')
        self.driver.execute_script(js_script, arguments)
        return self

    def execute_async_js_script(self, js_script, arguments=None):
        """
        Executes an asynchronous JavaScript script with optional arguments.

        :param js_script: The JavaScript script to execute
        :param arguments: Optional arguments for the script
        :return: self
        """
        log.info(f'Execute async JS script: {js_script} with arguments: {arguments}')
        self.driver.execute_async_script(js_script, arguments)
        return self

    def delete_all_cookies(self):
        """
        Deletes all cookies in the scope of the session.

        :return: self
        """
        log.info(f'Delete all cookies in the scope of the session')
        self.driver.delete_all_cookies()
        return self

    def delete_cookie(self, cookie_to_delete):
        """
        Deletes a specific cookie.

        :param cookie_to_delete: The name of the cookie to delete
        :return: self
        """
        log.info(f'Deleting cookie: {cookie_to_delete}')
        self.driver.delete_cookie(cookie_to_delete)
        return self

    def set_cookie(self, cookie_name: dict):
        """
        Sets a new cookie.

        :param cookie_name: A dictionary containing the cookie name and value
        """
        log.info(f'Setting cookie: {cookie_name}')
        self.driver.add_cookie(cookie_name)

    def get_all_cookies(self):
        """
        Returns a set of dictionaries corresponding to cookies visible in the current session.

        :return: self
        """
        log.info(f'Returns a set of dictionaries, corresponding to cookies visible in the current session')
        self.driver.get_cookies()
        return self

    def get_cookie(self, cookie):
        """
        Gets a single cookie.

        :param cookie: The name of the cookie to retrieve
        :return: self
        """
        log.info(f' Get a single cookie: {cookie}')
        self.driver.get_cookie(cookie)
        return self

    def switch_to_frame(self, frame_id):
        """
        Switches the WebDriver focus to the specified frame.

        :param frame_id: The ID of the frame to switch to
        :return: self
        """
        log.info(f'Switching to frame: {frame_id}')
        self.driver.switch_to.frame(frame_id)
        return self

    def switch_to_default(self):
        """
        Switches the WebDriver focus to the default frame.

        :return: self
        """
        log.info(f'Switching focus to the default frame')
        self.driver.switch_to.default_content()
        return self

    def dismiss_alert(self):
        """
        Dismisses the alert.

        :return: self
        """
        log.info(f'Dismissing the alert')
        self.driver.switch_to.alert.dismiss()
        return self

    def accept_alert(self):
        """
        Accepts the alert.

        :return: self
        """
        log.info(f'Accepting alert')
        self.driver.switch_to.alert.accept()
        return self

    def type_in_alert(self, value):
        """
        Types the specified value in the alert.

        :param value: The value to type in the alert
        :return: self
        """
        log.info(f'Typing in alert: {value}')
        self.driver.switch_to.alert.text(value)
        return self

    def click_with_delay(self, selector, delay=2):
        """
        Clicks on an element only after it becomes visible and adds an additional delay before click.

        :param selector: The element to click on
        :param delay: The additional delay in seconds (default is 2)
        :return: self
        """
        self.waiter.wait_for_element_to_be_visible(selector)
        self.waiter.strict_wait(delay)
        log.info(f'Clicking on element: {selector} with delay: {delay}')
        self.finder.find(selector).click()

    def click(self, selector):
        """
        Clicks on an element after it becomes visible.

        :param selector: The element to click on
        :return: self
        """
        self.waiter.wait_for_element_to_be_visible(selector)
        log.info(f'Clicking on element: {selector}')
        self.finder.find(selector).click()

    def open_new_window(self):
        """
        Opens a new window and switches to new window

        :return: self
        """
        log.info(f'Opening new window')
        self.driver.switch_to.new_window('window')

    def open_new_tab(self):
        """
        Opens a new tab and switches to it

        :return: self
        """
        log.info(f'Opening new tab')
        self.driver.switch_to.new_window('tab')

    def scroll_to(self, selector):
        """
        Scrolls to an element.

        :param selector: The element to scroll to
        :return: self
        """
        target = self.finder.find(selector)
        log.info(f'Scrolling to element: {selector}')
        self.execute_js_script('arguments[0].scrollIntoView({block: "center"})', target)

    def get_text_from_element(self, selector):
        """
        Gets the text from an element after it becomes visible.

        :param selector: The element to get text from
        :return: The text of the element
        """
        self.waiter.wait_for_element_to_be_visible(selector)
        log.info(f'Getting text from element: {selector}')
        return self.finder.find(selector).text

    def fill_field(self, selector, value):
        """
        Fills a field with a specified value after the field becomes visible.

        :param selector: The field to fill
        :param value: The value to fill in the field
        :return: self
        """
        self.waiter.wait_for_element_to_be_visible(selector)
        log.info(f'Filling field: {selector} with value: {value}')
        self.finder.find(selector).send_keys(value)
        return self

    def fill_form(self, selector_data):
        """
        Fills multiple fields in a form using a dictionary of selectors and values.

        :param selector_data: A dictionary of selectors and values
        :return: self
        """
        if type(selector_data) is dict:
            for selector, data in selector_data.items():
                self.waiter.wait_for_element_to_be_visible(selector)
                log.info(f'Filling field: {selector} with value: {data}')
                self.finder.find(selector).send_keys(data)
        return self

    def move_mouse_on_element(self, selector):
        """
        Moves the mouse cursor over an element after the element becomes visible.

        :param selector: The element to move the mouse cursor over
        :return: self
        """
        self.waiter.wait_for_element_to_be_visible(selector)
        element = self.finder.find(selector)
        log.info(f'Moving mouse on element: {selector}')
        ActionChains(self.driver).move_to_element(element)
        return self

    def press_key(self, key):
        """
        Presses a specified key.

        :param key: The key to press
        :return: self
        """
        log.info(f'Pressing key: {key}')
        actions = ActionChains(self.driver)
        actions.send_keys(key).perform()
        return self

    def send_keys(self, selector, keys):
        """
        Sends keys to a specified field.

        :param selector: The field to send keys to
        :param keys: The keys to send
        :return: self
        """
        log.info(f'Send keys: {keys} to the field: {selector}')
        self.finder.find(selector).send_keys(keys)
        return self

    def submit_form(self, selector):
        """
        Submits a form using a specified selector.

        :param selector: The form to submit
        :return: self
        """
        log.info(f'Submitting form: {selector}')
        self.finder.find(selector).submit()
        return self

    def switch_to_next_tab(self):
        """
        Switch to the next tab

        :return: self
        """
        window_handles = self.driver.window_handles
        current_tab_index = window_handles.index(self.driver.current_window_handle)
        next_tab_index = (current_tab_index + 1) % len(window_handles)
        log.info(f'Switching to the next tab')
        self.driver.switch_to.window(window_handles[next_tab_index])
        return self

    def switch_to_previous_tab(self):
        """
        Switch to the previous tab

        :return: self
        """
        window_handles = self.driver.window_handles
        current_tab_index = window_handles.index(self.driver.current_window_handle)
        next_tab_index = (current_tab_index - 1) % len(window_handles)
        log.info(f'Switching to the previous tab')
        self.driver.switch_to.window(window_handles[next_tab_index])
        return self

    def switch_to_window(self, window_name: str):
        """
        Switch to the window identify by window name(title).

        :param  window_name: Window title to switch on
        :return: self
        """
        # Iterate through all window handles
        for handle in self.driver.window_handles:
            self.driver.switch_to.window(handle)
            if self.driver.title == window_name:
                log.info(f'Switching to the window {window_name}')
                break
        return self

    def clear_field(self, selector):
        """
        Clears a field after it becomes visible.

        :param selector: The field to clear
        :return: self
        """
        self.waiter.wait_for_element_to_be_visible(selector)
        log.info(f'Clearing field: {selector}')
        self.finder.find(selector).clear()
        return self



import os
import json
from dotenv import load_dotenv, find_dotenv


def check_env_variables_exist(variables):
    missing_variables = []
    for variable in variables:
        if variable not in os.environ:
            missing_variables.append(variable)

    if missing_variables:
        raise ValueError(f"Environment variables are missing: {', '.join(missing_variables)}")

    return True


def check_json_file_exist(filename):
    current_dir = os.getcwd()

    while True:
        for root, dirs, files in os.walk(current_dir):
            if filename in files:
                return True

        parent_dir = os.path.dirname(current_dir)
        # Check if reached the root directory
        if current_dir == parent_dir:
            break
        current_dir = parent_dir

    return False


def find_json_file(filename):
    current_dir = os.getcwd()

    while True:
        for root, dirs, files in os.walk(current_dir):
            if filename in files:
                return os.path.join(root, filename)

        parent_dir = os.path.dirname(current_dir)
        # Check if reached the root directory
        if current_dir == parent_dir:
            break
        current_dir = parent_dir

    return None


def set_env_variables_from_json(filename):
    json_file_path = find_json_file(filename)
    if json_file_path is None:
        print(f"JSON file '{filename}' not found in the project's root directory or its subdirectories.")
        return

    with open(json_file_path, 'r') as file:
        data = json.load(file)

    for key, value in data.items():
        os.environ[key] = str(value)


env_variables = ['BASE_URL', 'SELENIUM_HOST', 'SELENIUM_BROWSER', 'WAIT_TIMEOUT', 'LOGGER_LEVEL']
json_configuration_file = 'vigilant.json'
env_configuration_file = '.vigilant.env'

if find_dotenv(env_configuration_file):
    print("Setting configuration from .vigilant.env file.")
    load_dotenv(env_configuration_file)
elif check_json_file_exist(json_configuration_file):
    print("Setting configuration from .vigilant.json file.")
    set_env_variables_from_json(json_configuration_file)
else:
    print("Could not find nor `.vigilant.env` nor `vigilant.json` configuration files.")
    print("If you don't want to use `.vigilant.env` nor `vigilant.json` configuration files - make sure, "
          "that you provide all configuration data as environment variables through  the way that is acceptable for "
          "you (pipeline configuration, custom bash script, etc.).")
    if check_env_variables_exist(env_variables):
        print("All mandatory environment variables exist.")



#!/usr/bin/env python

import click
from .install_webdriver_command import install_webdriver
from .install_standalone_command import install_selenium_standalone
from .install_dev_kit_command import install_dev_kit

from .run_selenium_command import run_selenium_server


@click.group(name="vgl.py")
def vgl():
    pass


@click.group(name="install", help="Install commands")
def install_group():
    pass


@click.group(name="run", help="Run commands")
def run_group():
    pass


run_group.add_command(run_selenium_server)


install_group.add_command(install_webdriver)
install_group.add_command(install_selenium_standalone)
install_group.add_command(install_dev_kit)

vgl.add_command(install_group)
vgl.add_command(run_group)


if __name__ == '__main__':
    vgl()



import os
import sys
import re
from pathlib import Path


def process_file(file_path):
    with open(file_path) as f:
        content = f.read()

    pattern = r'def\s+(\w+\([^)]*\))[^{]*?"""([^"""]*)"""'
    matches = re.finditer(pattern, content, re.MULTILINE | re.DOTALL)

    functions = []

    for match in matches:
        func_name = match.group(1)
        if '__init__' in func_name:
            continue

        docstring = match.group(2)
        line_number = content[:match.start()].count('\n') + 1

        functions.append({
            'func_name': func_name,
            'docstring': docstring,
            'line_number': line_number,
            'file_path': file_path
        })

    return functions


def generate_md_docs(target_directory, output_file):
    all_functions = []

    for root, _, files in os.walk(target_directory):
        for file in files:
            if file.endswith(".py"):
                file_path = os.path.join(root, file)
                all_functions.extend(process_file(file_path))

    # Sort the functions alphabetically
    all_functions.sort(key=lambda x: x['func_name'])

    # Write the table of contents and the functions to the output file
    with open(output_file, "w") as f:
        f.write("# Table of Contents\n\n")
        for func in all_functions:
            func_name = func['func_name']
            func_name_no_args = re.sub(r'\([^)]*\)', '', func_name)
            anchor = func_name_no_args.replace(" ", "")
            f.write(f"- [{func_name_no_args}](#{anchor})\n")
        f.write("\n")

        for func in all_functions:
            func_name = func['func_name']
            func_name_no_args = re.sub(r'\([^)]*\)', '', func_name)
            docstring = func['docstring']
            line_number = func['line_number']
            file_path = func['file_path']

            f.write(f"## {func_name_no_args}\n\n")
            f.write(f"{docstring}\n\n")

            f.write(
                f"```python\n# {file_path} (line {line_number})\ndef {func_name} -> return_type:\n    \"\"\"{docstring}\"\"\"\n    # Function code goes here\n```\n\n")


if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("Usage: python script.py <target_directory>")
        sys.exit(1)

    target_directory = Path(sys.argv[1])
    output_file = "documentation.md"

    # Remove existing output file if it exists
    if os.path.exists(output_file):
        os.remove(output_file)

    generate_md_docs(target_directory, output_file)



import click
import os
import platform
import requests
import tarfile
import zipfile

BROWSER_VERSIONS = {
    "chrome": "https://chromedriver.storage.googleapis.com/LATEST_RELEASE",
    "firefox": "https://api.github.com/repos/mozilla/geckodriver/releases/latest",
    "edge": "https://msedgedriver.azureedge.net/LATEST_RELEASE"
}


def get_browser_version(browser):
    if browser == "chrome":
        # Get the latest version of Chrome from the output of the "google-chrome --version" command
        chrome_version = os.popen("google-chrome --version").read().strip().split()[-1]
        return chrome_version
    elif browser == "firefox":
        # Get the latest version of Firefox from the output of the "firefox --version" command
        firefox_version = os.popen("firefox --version").read().strip().split()[-1]
        return firefox_version.split('.')[0]
    elif browser == "edge":
        try:
            # Get the latest version of Edge from the output of the "msedge --version" command
            edge_version = os.popen("msedge --version").read().strip().split()[-1]
            return edge_version.split('.')[0]
        except IndexError:
            click.echo(f"Failed to get {browser} version")
            return None
    else:
        click.echo(f"{browser} is not a supported browser")
        return None


def download_driver(browser, version):
    download_url = None
    if browser in BROWSER_VERSIONS:
        if browser == "chrome":
            # Get the major version of the Chrome browser installed on the machine
            chrome_version = get_browser_version(browser)
            if chrome_version is None:
                click.secho(f"{browser} is not installed on this machine.", fg="red")
                return
            # Use the ChromeDriver API to get the latest version of the ChromeDriver that is compatible with the installed Chrome browser
            response = requests.get(f"https://chromedriver.storage.googleapis.com/LATEST_RELEASE_{chrome_version.split('.')[0]}")
            if response.status_code == 200:
                latest_version = response.text
                download_url = f"https://chromedriver.storage.googleapis.com/{latest_version}/chromedriver_{platform.system().lower()}64.zip"
            else:
                click.secho(f"Could not find latest {browser} driver version.", fg="red")
        elif browser == "firefox":
            r = requests.get(BROWSER_VERSIONS[browser])
            release_info = r.json()
            for asset in release_info["assets"]:
                if platform.system().lower() in asset["name"] and "tar.gz" in asset["name"]:
                    download_url = asset["browser_download_url"]
                    break
            else:
                click.secho(f"Could not find latest {browser} driver version... Fail", fg="red")
        elif browser == "edge":
            download_url = f"https://msedgedriver.azureedge.net/{version}/edgedriver_{platform.system().lower()}.zip"
        else:
            click.secho(f"Invalid browser name '{browser}'", fg="red")
            return
    else:
        click.secho(f"Could not find browser '{browser}'.", fg="red")
        return

    if download_url is not None:
        response = requests.get(download_url)
        if download_url.endswith(".zip"):
            with open(f"selenium-server/{browser}_driver.zip", "wb") as f:
                f.write(response.content)
            with zipfile.ZipFile(f"selenium-server/{browser}_driver.zip", 'r') as zip_ref:
                for member in zip_ref.namelist():
                    zip_ref.extract(member, f"selenium-server/{browser}_driver/")
        elif download_url.endswith(".tar.gz"):
            with open(f"selenium-server/{browser}_driver.tar.gz", "wb") as f:
                f.write(response.content)
            with tarfile.open(f"selenium-server/{browser}_driver.tar.gz", 'r:gz') as tar_ref:
                tar_ref.extractall(f"selenium-server/{browser}_driver/")
    else:
        click.secho(f"Could not find download URL for {browser} driver.", fg="red")


def check_version_and_download_driver(browser):
    version = get_browser_version(browser)
    if version is None:
        click.secho(f"{browser} is not installed on this machine", fg="red")
    else:
        click.secho(f"Found: {browser} browser, version {version}.", fg="cyan")
        # Download the driver for the browser
        click.echo(f"Downloading driver for {browser} browser ... ", nl=False)
        download_driver(browser, version)
        click.secho("OK", fg="green")


@click.command(name='webdriver', help="Install the webdriver for a chosen browser.")
@click.option('-b', '--browser', type=click.Choice(['chrome', 'firefox', 'edge']), required=True)
def install_webdriver(browser):
    # Create the selenium-server directory if it doesn't exist
    os.makedirs("selenium-server", exist_ok=True)

    # Check if the browser is installed and get its version
    check_version_and_download_driver(browser)


if __name__ == "__main__":
    install_webdriver()



import os
import click

SELENIUM_SERVER_JAR = "selenium-server/selenium-server-standalone.jar"


@click.command(name='selenium-server', help="Run Selenium Server JAR file")
@click.option('--port', '-p', type=int, default=4444, help="Port number for the server")
@click.option('--driver', '-D', multiple=True,
              help="Specify driver options (e.g. -Dwebdriver.chrome.driver=chromedriver)")
@click.option('--daemon', '-d', is_flag=True, help="Run the server as a daemon")
def run_selenium_server(port, driver, daemon):
    driver_options = " ".join(driver)
    cmd = f"java -jar {SELENIUM_SERVER_JAR} -port {port} {driver_options}"
    click.echo(f"Running Selenium Server with command:\n {cmd}")
    if daemon:
        cmd += " &"
    os.system(cmd)


if __name__ == "__main__":
    run_selenium_server()



import os
import time

from selenium.webdriver import Remote
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.support.ui import WebDriverWait

from vigilant.actions.finder import Finder
from vigilant.logger import logger as log


def get_timeout():
    return float(os.environ.get('WAIT_TIMEOUT'))


class Waiter:

    def __init__(self, driver, finder):
        self.driver: Remote = driver
        self.finder: Finder = finder

    def wait_for_element_to_be_clickable(self, selector: str):
        """
        Waits for the element with the specified selector to be clickable.

        :param selector: The element's selector
        :return: self
        """
        log.info(f"Waiting for element with selector: {selector} - to be clickable.")
        WebDriverWait(driver=self.driver, timeout=get_timeout()).until(
            EC.element_to_be_clickable(self.finder.by_xpath_or_css(selector))
        )
        return self

    def wait_for_element_to_be_visible(self, selector: str):
        """
        Waits for the element with the specified selector to be visible.

        :param selector: The element's selector
        :return: self
        """
        log.info(f"Waiting for element with selector: {selector} - to be visible.")
        WebDriverWait(driver=self.driver, timeout=get_timeout()).until(
            EC.visibility_of_element_located(self.finder.by_xpath_or_css(selector))
        )
        return self

    def wait_for_element_to_be_present_in_dom(self, selector: str):
        """
        Waits for the element with the specified selector to be present in the DOM.

        :param selector: The element's selector
        :return: self
        """
        log.info(f"Waiting for element with selector: {selector} - to be presented in DOM.")
        WebDriverWait(driver=self.driver, timeout=get_timeout()).until(
            EC.presence_of_element_located(self.finder.by_xpath_or_css(selector))
        )
        return self

    def wait_for_element_to_disappear(self, selector: str):
        """
        Waits for the element with the specified selector to disappear.

        :param selector: The element's selector
        :return: self
        """
        log.info(f"Waiting for element with selector: {selector} - to disappear.")
        WebDriverWait(driver=self.driver, timeout=get_timeout()).until(
            EC.invisibility_of_element_located(self.finder.by_xpath_or_css(selector))
        )
        return self

    def wait_for_text_to_be_present_in_element_value(self, selector: str, value_text: str):
        """
        Waits for the specified text to be present in the value of the element with the given selector.

        :param selector: The element's selector
        :param value_text: The text to wait for
        :return: self
        """
        log.info(f"Waiting for element with selector: {selector} - to disappear.")
        WebDriverWait(driver=self.driver, timeout=get_timeout()).until(
            EC.text_to_be_present_in_element_value(self.finder.by_xpath_or_css(selector), value_text)
        )
        return self

    def wait_for_text_to_be_present_in_element(self, selector: str, text: str):
        """
        Waits for the specified text to be present in the element with the given selector.

        :param selector: The element's selector
        :param text: The text to wait for
        :return: self
        """
        log.info(f"Waiting for element with selector: {selector} - to disappear.")
        WebDriverWait(driver=self.driver, timeout=get_timeout()).until(
            EC.text_to_be_present_in_element(self.finder.by_xpath_or_css(selector), text)
        )
        return self

    def wait_for_text_to_be_present_in_element_attribute(self, selector: str, text_in_attribute: str):
        """
        Waits for the specified text to be present in the attribute of the element with the given selector.

        :param selector: The element's selector
        :param text_in_attribute: The text to wait for
        :return: self
        """
        log.info(f"Waiting for element with selector: {selector} - to disappear.")
        WebDriverWait(driver=self.driver, timeout=get_timeout()).until(
            EC.text_to_be_present_in_element_attribute(self.finder.by_xpath_or_css(selector), text_in_attribute)
        )
        return self

    def wait_for_alert_(self, selector: str):
        """
        Waits for an alert to be present.

        :param selector: The element's selector
        :return: self
        """
        log.info(f"Waiting for element with selector: {selector} - to disappear.")
        WebDriverWait(driver=self.driver, timeout=get_timeout()).until(
            EC.alert_is_present()
        )
        return self

    def strict_wait(self, seconds: int):
        """
        Waits for the specified number of seconds.

        :param seconds: The number of seconds to wait
        :return: self
        """
        log.info(f"Strict wait for {seconds} seconds")
        time.sleep(seconds)
        return self
